<xsl:stylesheet
     xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
     version="1.0">

<!-- ####################################### -->
<!-- ####################################### -->
<!-- Write slideshow html pages -->
<xsl:template match="album" mode="slideshows">
<xsl:for-each select="subalbum">

  <xsl:if test="count(photo)">

  <xsl:variable name="subalbumNumber" select="position()"/>
  <xsl:variable name="photoCount" select="count(photo)"/>
  <xsl:document method="html" indent="yes" href="{concat($outputPath, '/subalbum_', string(position()), '_slideshow.html')}">
    <html>
      <head>
        <meta name="generator" content="Album Shaper (c.) Will Stokes"/>
        <style type="text/html">
          &lt;!--
          A{text-decoration:none}
          --&gt;
        </style>
        <style type="text/css">
          &lt;!--
          h3 {font-size: 12pt; font-weight: bold; text-align: center}
          h4 {font-size: 10pt; font-weight: normal; text-align: center}
          h4.ital {font-size: 10pt; font-weight: normal; text-align: center}
          --&gt;
        </style>
        <title><xsl:value-of select="name"/></title>
        <script type="text/javascript" language="JavaScript">
        <![CDATA[
        <!-- HIDE FROM OLD BROWSERS
        var imageNumber=1

        var photoTitles = new Array(]]><xsl:value-of select="count(photo)"/><![CDATA[);

        ]]>
        <xsl:for-each select="photo">
          <xsl:variable name="photoDescription" select="description"/>
          photoTitles[<xsl:value-of select="position()-1"/>] = <![CDATA["]]><xsl:call-template name="JavaScriptString">
                                      <xsl:with-param name="string" select="$photoDescription"/>
                                     </xsl:call-template><![CDATA["]]>;
        </xsl:for-each>
        <![CDATA[

        //######################################
        //Define functions used to change images
        //######################################
        function expandImage()
        {
          fileToOpen = "img/]]><xsl:value-of select="$subalbumNumber"/><![CDATA[/"+imageNumber+".jpg"
          new_window = window.open(fileToOpen,'albulmifyRules')
        }

        function reloadImage()
        {
          document.currentPhoto.src="img/]]><xsl:value-of select="$subalbumNumber"/><![CDATA[/"+imageNumber+"_slideshow.jpg"
          document.currentPhoto.alt=photoTitles[imageNumber-1];
          document.getElementById("photoNum").lastChild.nodeValue="Photo " + imageNumber + " of ]]><xsl:value-of select="count(photo)"/><![CDATA["
          document.getElementById("photoDesc").lastChild.nodeValue=photoTitles[imageNumber-1];
        }

        function firstImage()
        {
          //set image number to first
          imageNumber = 1

          //reset image src value based on variable
          reloadImage()
        }

        function lastImage()
        {
          //set image number to last
          imageNumber = ]]><xsl:value-of select="count(photo)"/><![CDATA[

          //reset image src value based on variable
          reloadImage()
        }

        function nextImage()
        {
          //increment image number
          imageNumber = imageNumber + 1

          //wrap to begining if reached the end
          if (imageNumber==]]><xsl:value-of select="1 + count(photo)"/><![CDATA[)
          {imageNumber = 1}

          //reset image src value based on variable
          reloadImage()
        }

        function previousImage()
        {
          //decrement image number
          imageNumber = imageNumber - 1
          //wrap to begining if reached the end
          if (imageNumber==(1 - 1))
          {imageNumber = ]]><xsl:value-of select="count(photo)"/><![CDATA[}

          //reset image src value based on variable
          reloadImage()
        }
        -->
        ]]>
        </script>
      </head>
      <body bgcolor="white" text="black">
        <center>
          <table border="0" cellpadding="0" cellspacing="0">

<!-- ############################ -->
<!-- ### Top Border           ### -->
<!-- ############################ -->
<tr>
  <td style="background-image: url(resources/topLeft.png);" width="16" height="16"></td>
  <td style="background-image: url(resources/horizontal.png); background-repeat:repeat-x;" height="16"></td>
  <td style="background-image: url(resources/topRight.png);" width="16" height="16"></td>
</tr>

<!-- ##################################### -->
<!-- ### Subalbum Name and Description ### -->
<!-- ##################################### -->
<tr>
  <td style="background-image: url(resources/vertical.png); background-repeat:repeat-y;" width="16"></td>
  <td width="450" align="center">
    <h3><xsl:value-of select="name"/></h3>
    <h4><xsl:value-of select="description"/></h4>
  </td>
  <td style="background-image: url(resources/vertical.png); background-repeat:repeat-y;" width="16"> </td>
</tr>

<!-- ############################ -->
<!-- ### Photo                ### -->
<!-- ############################ -->
<tr>
  <td style="background-image: url(resources/vertical.png); background-repeat:repeat-y;" width="16"></td>
  <td>
    <center><a href="JavaScript:expandImage()">
        <img alt="current photo" src="img/{$subalbumNumber}/1_slideshow.jpg" name="currentPhoto" border="0"/>
    </a></center>
  </td>
  <td style="background-image: url(resources/vertical.png); background-repeat:repeat-y;" width="16"></td>
</tr>

<!-- ################################## -->
<!-- ### Control Buttons and Photo Info -->
<!-- ################################## -->
<tr>
  <td style="background-image: url(resources/vertical.png); background-repeat:repeat-y;" width="16"></td>
  <td align="center">
    <table border="0">
      <tr>
        <td valign="middle" align="center" width="70">
          <a href="JavaScript:firstImage()"> <img src="resources/first.png" alt="first" border="0"/> </a>
        </td>
        <td valign="middle" align="center" width="70">
          <a href="JavaScript:previousImage()"> <img src="resources/prev.png" alt="previous" border="0"/> </a>
        </td>
        <td valign="middle" align="center" width="170">
          <div width="100%" align="center" id="photoNum">Photo 1 of <xsl:value-of select="$photoCount"/></div>
        </td>
        <td valign="middle" align="center" width="70">
          <a href="JavaScript:nextImage()"> <img src="resources/next.png" alt="next" border="0"/> </a>
        </td>
        <td valign="middle" align="center" width="70">
          <a href="JavaScript:lastImage()"> <img src="resources/last.png" alt="last" border="0"/> </a>
        </td>
      </tr>
    </table>
  </td>
  <td style="background-image: url(resources/vertical.png); background-repeat:repeat-y;" width="16"></td>
</tr>
<tr>
  <td style="background-image: url(resources/vertical.png); background-repeat:repeat-y;" width="16"></td>
  <td valign="middle" width="450" height="20" align="justify">
    <div align="center" width="100%" height="100%" id="photoDesc"><xsl:value-of select="photo/description"/>

          <xsl:text disable-output-escaping="yes"><![CDATA[&nbsp;&nbsp;]]></xsl:text>
</div>
  </td>
  <td style="background-image: url(resources/vertical.png); background-repeat:repeat-y;" width="16"></td>
</tr>

<!-- ############################ -->
<!-- ### Horizontal Separator ### -->
<!-- ############################ -->
<tr>
  <td style="background-image: url(resources/leftJoint.png);" width="16" height="16"></td>
  <td style="background-image: url(resources/horizontal.png); background-repeat:repeat-x;" height="16"></td>
  <td style="background-image: url(resources/rightJoint.png);" width="16" height="16"></td>
</tr>

<!-- ######################################### -->
<!-- ### Album Links and Album Shaper Link ### -->
<!-- ######################################### -->
<tr>
  <td style="background-image: url(resources/vertical.png); background-repeat:repeat-y;" width="16"></td>
  <td align="center">
    <table border="0">
      <tr>
        <td valign="middle">
          <a href="subalbum_{position()}_thumbs.html"><img src="resources/otherLayout.png" border="0"/></a>
        </td>
        <td valign="middle">
          <h4><a href="subalbum_{position()}_thumbs.html">Thumbnails</a></h4>
        </td>
        <td>
          <xsl:text disable-output-escaping="yes"><![CDATA[&nbsp;&nbsp;]]></xsl:text>
        </td>
        <td valign="middle">
          <a href="Album.html"><img src="resources/contents.png" border="0" alt="Album Index"/></a>
        </td>
        <td valign="middle">
          <h4><a href="Album.html">Album Index</a></h4>
        </td>
      </tr>
    </table>
  </td>
  <td style="background-image: url(resources/vertical.png); background-repeat:repeat-y;" width="16"></td>
</tr>
<tr>
  <td style="background-image: url(resources/vertical.png); background-repeat:repeat-y;" width="16"></td>
  <td align="center">
    <h4 class="ital">(Generated by <a href="http://albumshaper.sourceforge.net">Album Shaper</a>, Slick theme)</h4>
  </td>
  <td style="background-image: url(resources/vertical.png); background-repeat:repeat-y;" width="16"></td>
</tr>

<!-- ##################### -->
<!-- ### Bottom Border ### -->
<!-- ##################### -->
<tr>
  <td style="background-image: url(resources/bottomLeft.png);" width="16" height="16"></td>
  <td style="background-image: url(resources/horizontal.png); background-repeat:repeat-x;" height="16"></td>
  <td style="background-image: url(resources/bottomRight.png);" width="16" height="16"></td>
</tr>

          </table>
        </center>
      </body>
    </html>
  </xsl:document>

</xsl:if>

</xsl:for-each>
</xsl:template>
<!-- ####################################### -->
<!-- ####################################### -->

</xsl:stylesheet>
